@@ -1,4 +1,4 @@
-{-# LANGUAGE TypeSynonymInstances, FlexibleInstances #-}
+{-# LANGUAGE CPP, TypeSynonymInstances, FlexibleInstances #-}
 {-# OPTIONS_GHC -fno-warn-orphans #-}
 module Test.QuickCheck.IO where
 
@@ -11,5 +11,9 @@ instance Testable Assertion where
   exhaustive _ = True
 
 propertyIO :: Assertion -> Property
+#if MIN_VERSION_QuickCheck(2,7,0)
+propertyIO action = ioProperty $ do
+#else
 propertyIO action = morallyDubiousIOProperty $ do
+#endif
   (action >> return succeeded) `E.catch` \(HUnitFailure err) -> return failed {reason = err}
